package com.jjt.emp.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.emp.domain.TwinEmpDetail;

/**
 * 员工排班明细Mapper接口
 * 
 * @author wukai
 * @date 2025-01-18
 */
public interface TwinEmpDetailMapper extends BaseMapper<TwinEmpDetail>
{
    /**
     * 查询员工排班明细
     * 
     * @param detailId 员工排班明细主键
     * @return 员工排班明细
     */
    public TwinEmpDetail selectTwinEmpDetailByDetailId(Long detailId);

    /**
     * 查询员工排班明细列表
     * 
     * @param twinEmpDetail 员工排班明细
     * @return 员工排班明细集合
     */
    public List<TwinEmpDetail> selectTwinEmpDetailList(TwinEmpDetail twinEmpDetail);

    /**
     * 新增员工排班明细
     * 
     * @param twinEmpDetail 员工排班明细
     * @return 结果
     */
    public int insertTwinEmpDetail(TwinEmpDetail twinEmpDetail);

    /**
     * 修改员工排班明细
     * 
     * @param twinEmpDetail 员工排班明细
     * @return 结果
     */
    public int updateTwinEmpDetail(TwinEmpDetail twinEmpDetail);

    /**
     * 删除员工排班明细
     * 
     * @param detailId 员工排班明细主键
     * @return 结果
     */
    public int deleteTwinEmpDetailByDetailId(Long detailId);

    /**
     * 批量删除员工排班明细
     * 
     * @param detailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinEmpDetailByDetailIds(Long[] detailIds);
}
